job "mysql-server" {
  datacenters = ["dc1"]
  type = "service"
  priority = 80

  group "mysql-server" {
    count = 1

    restart {
      attempts = 10
      interval = "5m"
      delay = "25s"
      mode = "delay"
    }

    network {
      mode = "bridge"

      port "db" {
        to = 3306
      }
      port "envoy_metrics" {
        to = 9123
      }
    }

    volume "mysql-data" {
      type = "host"
      read_only = false
      source = "mysql-data"
    }

    service {
      name = "mysql-server"
      provider = "nomad"
      port = "db"
    }

    task "mysql-server" {
      driver = "docker"

      config {
        image = "mariadb:10"
        ports = ["db"]
        args = ["--innodb-buffer-pool-size=1G"]
      }

      volume_mount {
        volume = "mysql-data"
        destination = "/var/lib/mysql"
        read_only = false
      }

      env = {
        # Allow connections from any host
        "MYSQL_ROOT_HOST" = "%"
      }

      template {
        data = <<EOH
{{ with nomadVar "nomad/jobs" }}
MYSQL_ROOT_PASSWORD={{ .mysql_root_password }}
{{ end }}
        EOH
        destination = "secrets/db.env"
        env = true
      }

      resources {
        cpu = 300
        memory = 1024
      }
    }
  }
}
