resource "nomad_job" "service" {
  jobspec = templatefile("${path.module}/service_template.nomad", {
    name               = var.name
    image              = var.image
    image_pull_timeout = var.image_pull_timeout
    args               = var.args
    env                = var.env
    meta               = var.meta
    group_meta         = var.group_meta

    service_port = var.service_port
    sticky_disk  = var.sticky_disk
    resources    = var.resources

    ingress             = var.ingress
    ingress_rule        = var.ingress_rule
    ingress_middlewares = var.ingress_middlewares
    healthcheck_path    = var.healthcheck_path
    metrics_port_name   = var.metrics_port_name

    templates    = var.templates
    host_volumes = var.host_volumes

    connect   = anytrue([var.ingress, var.use_mysql, var.use_redis, var.use_ldap, length(var.upstreams) > 0])
    upstreams = var.upstreams
    use_mysql = var.use_mysql
    use_redis = var.use_redis
    use_ldap  = var.use_ldap
    use_vault = var.use_vault

    mysql_bootstrap = var.mysql_bootstrap
  })
}
